<?php

namespace Litecms\BookingSystem\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\BookingSystem\Models\BookingSystem;

class BookingSystemPolicy
{

    /**
     * Determine if the given user can view the booking_system.
     *
     * @param UserPolicy $user
     * @param BookingSystem $booking_system
     *
     * @return bool
     */
    public function view(UserPolicy $user, BookingSystem $booking_system)
    {
        if ($user->canDo('booking_system.booking_system.view') && $user->isAdmin()) {
            return true;
        }

        return $booking_system->user_id == user_id() && $booking_system->user_type == user_type();
    }

    /**
     * Determine if the given user can create a booking_system.
     *
     * @param UserPolicy $user
     * @param BookingSystem $booking_system
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('booking_system.booking_system.create');
    }

    /**
     * Determine if the given user can update the given booking_system.
     *
     * @param UserPolicy $user
     * @param BookingSystem $booking_system
     *
     * @return bool
     */
    public function update(UserPolicy $user, BookingSystem $booking_system)
    {
        if ($user->canDo('booking_system.booking_system.edit') && $user->isAdmin()) {
            return true;
        }

        return $booking_system->user_id == user_id() && $booking_system->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given booking_system.
     *
     * @param UserPolicy $user
     * @param BookingSystem $booking_system
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BookingSystem $booking_system)
    {
        return $booking_system->user_id == user_id() && $booking_system->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given booking_system.
     *
     * @param UserPolicy $user
     * @param BookingSystem $booking_system
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BookingSystem $booking_system)
    {
        if ($user->canDo('booking_system.booking_system.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given booking_system.
     *
     * @param UserPolicy $user
     * @param BookingSystem $booking_system
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BookingSystem $booking_system)
    {
        if ($user->canDo('booking_system.booking_system.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
