<?php

namespace Litecms\BookingSystem\Providers;

use Illuminate\Support\ServiceProvider;

class BookingSystemServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'booking_system');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'booking_system');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.booking_system', function ($app) {
            return $this->app->make('Litecms\BookingSystem\BookingSystem');
        });

                // Bind BookingSystem to repository
        $this->app->bind(
            'Litecms\BookingSystem\Interfaces\BookingSystemRepositoryInterface',
            \Litecms\BookingSystem\Repositories\Eloquent\BookingSystemRepository::class
        );

        $this->app->register(\Litecms\BookingSystem\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\BookingSystem\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\BookingSystem\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.booking_system'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/booking_system.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/booking_system')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/booking_system')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
